@@ -66,7 +66,6 @@ mod access;
 mod addressblock;
 mod bitrange;
 mod cluster;
-mod clusterinfo;
 mod cpu;
 mod device;
 mod dimelement;
@@ -74,16 +73,13 @@ mod endian;
 mod enumeratedvalue;
 mod enumeratedvalues;
 mod field;
-mod fieldinfo;
 mod interrupt;
 mod modifiedwritevalues;
 mod peripheral;
-mod peripheralinfo;
 mod protection;
 mod readaction;
 mod register;
 mod registercluster;
-mod registerinfo;
 mod registerproperties;
 mod usage;
 mod writeconstraint;
